@@ -1,19 +1,18 @@
 #!/usr/bin/env python
 # -*- coding: utf_8 -*-
-
-
-from .scanner import Scanner
 from .core_matcher.pattern_matcher import PatternMatcher
-
+from .core_sgrep.semantic_sgrep import SemanticGrep
+from .scanner import Scanner
 
 __title__ = 'libsast'
 __authors__ = 'Ajin Abraham'
 __copyright__ = 'Copyright 2020 Ajin Abraham, OpenSecurity'
-__version__ = '1.0.0'
+__version__ = '1.0.2'
 __version_info__ = tuple(int(i) for i in __version__.split('.'))
 __all__ = [
     'Scanner',
     'PatternMatcher',
+    'SemanticGrep',
     '__title__',
     '__authors__',
     '__copyright__',
